# geoviz
Plotting library for chloropleths and other geo visualizations.
Choropleths can take in dataframes or csv files, and plot sequential, divergent, and categorical data. 

## See http://locusanalytics.github.io/files/geoviz_tutorial.html for tutorial/functionality.
